import express, { Request, Response } from "express";
import { handleFormData, fetchReports } from "./formHandler.js";
import { initDb } from "./database.js";
import { GenerateReportByDate } from "./reports/reports.js";

const app = express();
const port = process.env.PORT || 3000;

initDb();

app.use(express.static('static'));
app.use(express.json());

app.get("/test", (req: Request, res: Response) => {
    res.json({message: "TrACreport is running"});
});

app.post('/submit', (req, res) => {
  const report = req.body;
  handleFormData(report);
  res.status(200).json({ status: 'ok', message: 'Form received' });
});

app.get('/fetchall', async (req, res) => {
  try {
    const data = await fetchReports();
    res.status(200).json(data);
  } catch (error) {
    res.status(500).json({ error: 'Failed to fetch reports' });
  }
});

interface ReportQuery {
  start?: string;
  end?: string;
  password?: string;
};

const reportHandler = async (req: Request, res: Response) => {
  const { start, end, password } = req.query;

  if (password !== process.env.PASSWORD) {
    return res.status(401).send('Unauthorized');
  }

  if (!start || !end) {
    return res.status(400).send('Missing Parameters');
  }

  try {
    const startDate = new Date(start as string);
    const endDate = new Date(end as string);
    endDate.setHours(23, 59, 59, 999); // Set to end of day
    const html = await GenerateReportByDate(startDate, endDate);
    res.setHeader('Content-Type', 'text/html');
    res.send(html);
  } catch (err) {
    console.error('Report generation failed:', err);
    res.status(500).send('Error generating report');
  }
};

app.get('/report', reportHandler as express.RequestHandler);

app.listen(port, () => {
    console.log("Server running on port:", port);
});